@@ -12,21 +12,8 @@ import os
 import warnings
 import tempfile
 import urllib, urllib2
+import requests
  
-def log(message=""):
-    '''
-    This is useful for profiling the code in the browser,
-    but we just print the message in the local version
-    '''
-    print(message)
-
-def GET():
-    '''
-    This is deprecated. Also, it's useless if you're
-    running locally rather than as a CGI script.
-    '''
-    warnings.warn('Deprecated', DeprecationWarning)   
-
 def scrape (url, params = None, user_agent = None) :
     '''
     Scrape a URL optionally with parameters.
@@ -65,19 +52,20 @@ def pdftoxml(pdfdata):
     xmlin.close()
     return xmldata
 
-def jsviewcall(name, **args):
-    'callback to a view with parameter lists (cross language capability)'
-    url = "https://scraperwiki.com/views/%s/run/?%s" % (name, urllib.urlencode(args))
-    response = urllib.urlopen(url).read()
-    try:
-        return json.loads(response)
-    except ValueError:
-        return response
+def _in_box():
+  return os.path.isfile(os.path.expanduser("~/box.json"))
+
+def status(type, message=None):
+  assert type in ['ok', 'error']
+
+  # if not running in a ScraperWiki platform box, silently do nothing
+  if not _in_box():
+    return
+
+  # send status update to the box
+  r = requests.post("https://x.scraperwiki.com/api/status", data={'type':type, 'message':message})
+  r.raise_for_status()
+
+
 
-urllib2opener = None
-def urllibSetup(http_proxy):
-    raise NotImplementedError('Dunno what this does')
 
-class SWImporter(object):
-    def __init__(self, swinstance="https://scraperwiki.com"):
-        raise NotImplementedError('Standard Python imports are used instead')
